@@ -1,6 +1,6 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 """Python modules manipulation utility functions.
 
@@ -26,27 +26,33 @@ import os
 import sys
 import sysconfig
 import types
+import warnings
 from collections.abc import Callable, Iterable, Sequence
 from contextlib import redirect_stderr, redirect_stdout
 from functools import lru_cache
 from pathlib import Path
 
-from astroid.const import IS_JYTHON, IS_PYPY
+from astroid.const import IS_JYTHON, IS_PYPY, PY310_PLUS
 from astroid.interpreter._import import spec, util
 
+if PY310_PLUS:
+    from sys import stdlib_module_names
+else:
+    from astroid._backport_stdlib_names import stdlib_module_names
+
 logger = logging.getLogger(__name__)
 
 
 if sys.platform.startswith("win"):
-    PY_SOURCE_EXTS = ("py", "pyw")
+    PY_SOURCE_EXTS = ("py", "pyw", "pyi")
     PY_COMPILED_EXTS = ("dll", "pyd")
 else:
-    PY_SOURCE_EXTS = ("py",)
+    PY_SOURCE_EXTS = ("py", "pyi")
     PY_COMPILED_EXTS = ("so",)
 
 
 # TODO: Adding `platstdlib` is a fix for a workaround in virtualenv. At some point we should
-# revisit whether this is still necessary. See https://github.com/PyCQA/astroid/pull/1323.
+# revisit whether this is still necessary. See https://github.com/pylint-dev/astroid/pull/1323.
 STD_LIB_DIRS = {sysconfig.get_path("stdlib"), sysconfig.get_path("platstdlib")}
 
 if os.name == "nt":
@@ -74,7 +80,7 @@ if IS_PYPY and sys.version_info < (3, 8):
     STD_LIB_DIRS.add(str(Path(sysconfig.get_path("stdlib")).parent / "lib-python/3"))
 
     # TODO: This is a fix for a workaround in virtualenv. At some point we should revisit
-    # whether this is still necessary. See https://github.com/PyCQA/astroid/pull/1324.
+    # whether this is still necessary. See https://github.com/pylint-dev/astroid/pull/1324.
     STD_LIB_DIRS.add(str(Path(sysconfig.get_path("platstdlib")).parent / "lib_pypy"))
     STD_LIB_DIRS.add(
         str(Path(sysconfig.get_path("platstdlib")).parent / "lib-python/3")
@@ -102,7 +108,7 @@ if os.name == "posix":
         # standard library could be found. More details can be found
         # here http://bugs.python.org/issue1294959.
         # An easy reproducing case would be
-        # https://github.com/PyCQA/pylint/issues/712#issuecomment-163178753
+        # https://github.com/pylint-dev/pylint/issues/712#issuecomment-163178753
         STD_LIB_DIRS.add(_posix_path("lib64"))
 
 EXT_LIB_DIRS = {sysconfig.get_path("purelib"), sysconfig.get_path("platlib")}
@@ -110,8 +116,8 @@ BUILTIN_MODULES = dict.fromkeys(sys.builtin_module_names, True)
 
 
 class NoSourceFile(Exception):
-    """exception raised when we are not able to get a python
-    source file for a precompiled file
+    """Exception raised when we are not able to get a python
+    source file for a precompiled file.
     """
 
 
@@ -138,7 +144,7 @@ def _path_from_filename(filename: str, is_jython: bool = IS_JYTHON) -> str:
 def _handle_blacklist(
     blacklist: Sequence[str], dirnames: list[str], filenames: list[str]
 ) -> None:
-    """remove files/directories in the black list
+    """Remove files/directories in the black list.
 
     dirnames/filenames are usually from os.walk
     """
@@ -149,7 +155,7 @@ def _handle_blacklist(
             filenames.remove(norecurs)
 
 
-@lru_cache()
+@lru_cache
 def _cache_normalize_path_(path: str) -> str:
     return _normalize_path(path)
 
@@ -230,7 +236,7 @@ def load_module_from_file(filepath: str) -> types.ModuleType:
 
 
 def check_modpath_has_init(path: str, mod_path: list[str]) -> bool:
-    """check there are some __init__.py all along the way"""
+    """Check there are some __init__.py all along the way."""
     modpath: list[str] = []
     for part in mod_path:
         modpath.append(part)
@@ -243,7 +249,7 @@ def check_modpath_has_init(path: str, mod_path: list[str]) -> bool:
 
 
 def _get_relative_base_path(filename: str, path_to_check: str) -> list[str] | None:
-    """Extracts the relative mod path of the file to import from
+    """Extracts the relative mod path of the file to import from.
 
     Check if a file is within the passed in path and if so, returns the
     relative mod path from the one passed in.
@@ -268,9 +274,6 @@ def _get_relative_base_path(filename: str, path_to_check: str) -> list[str] | No
     if os.path.normcase(real_filename).startswith(path_to_check):
         importable_path = real_filename
 
-    # if "var" in path_to_check:
-    #     breakpoint()
-
     if importable_path:
         base_path = os.path.splitext(importable_path)[0]
         relative_base_path = base_path[len(path_to_check) :]
@@ -306,7 +309,7 @@ def modpath_from_file_with_callback(
 
 
 def modpath_from_file(filename: str, path: Sequence[str] | None = None) -> list[str]:
-    """Get the corresponding split module's name from a filename
+    """Get the corresponding split module's name from a filename.
 
     This function will return the name of a module or package split on `.`.
 
@@ -339,9 +342,10 @@ def file_info_from_modpath(
     path: Sequence[str] | None = None,
     context_file: str | None = None,
 ) -> spec.ModuleSpec:
-    """given a mod path (i.e. split module / package name), return the
-    corresponding file, giving priority to source file over precompiled
-    file if it exists
+    """Given a mod path (i.e. split module / package name), return the
+    corresponding file.
+
+    Giving priority to source file over precompiled file if it exists.
 
     :param modpath:
       split module's name (i.e name of a module or package split
@@ -385,7 +389,7 @@ def file_info_from_modpath(
 
 
 def get_module_part(dotted_name: str, context_file: str | None = None) -> str:
-    """given a dotted name return the module part of the name :
+    """Given a dotted name return the module part of the name :
 
     >>> get_module_part('astroid.as_string.dump')
     'astroid.as_string'
@@ -397,7 +401,6 @@ def get_module_part(dotted_name: str, context_file: str | None = None) -> str:
       introduced using a relative import unresolvable in the actual
       context (i.e. modutils)
 
-
     :raise ImportError: if there is no such module in the directory
 
     :return:
@@ -427,7 +430,8 @@ def get_module_part(dotted_name: str, context_file: str | None = None) -> str:
         ), "explicit relative import, but no context_file?"
         path = []  # prevent resolving the import non-relatively
         starti = 1
-    while parts[starti] == "":  # for all further dots: change context
+    # for all further dots: change context
+    while starti < len(parts) and parts[starti] == "":
         starti += 1
         assert (
             context_file is not None
@@ -448,8 +452,8 @@ def get_module_part(dotted_name: str, context_file: str | None = None) -> str:
 def get_module_files(
     src_directory: str, blacklist: Sequence[str], list_all: bool = False
 ) -> list[str]:
-    """given a package directory return a list of all available python
-    module's files in the package and its subpackages
+    """Given a package directory return a list of all available python
+    module's files in the package and its subpackages.
 
     :param src_directory:
       path of the directory corresponding to the package
@@ -470,7 +474,7 @@ def get_module_files(
             continue
         _handle_blacklist(blacklist, dirnames, filenames)
         # check for __init__.py
-        if not list_all and "__init__.py" not in filenames:
+        if not list_all and {"__init__.py", "__init__.pyi"}.isdisjoint(filenames):
             dirnames[:] = ()
             continue
         for filename in filenames:
@@ -481,9 +485,9 @@ def get_module_files(
 
 
 def get_source_file(filename: str, include_no_ext: bool = False) -> str:
-    """given a python module's file name return the matching source file
+    """Given a python module's file name return the matching source file
     name (the filename will be returned identically if it's already an
-    absolute path to a python source file...)
+    absolute path to a python source file).
 
     :param filename: python module's file name
 
@@ -493,6 +497,8 @@ def get_source_file(filename: str, include_no_ext: bool = False) -> str:
     """
     filename = os.path.abspath(_path_from_filename(filename))
     base, orig_ext = os.path.splitext(filename)
+    if orig_ext == ".pyi" and os.path.exists(f"{base}{orig_ext}"):
+        return f"{base}{orig_ext}"
     for ext in PY_SOURCE_EXTS:
         source_path = f"{base}.{ext}"
         if os.path.exists(source_path):
@@ -503,17 +509,50 @@ def get_source_file(filename: str, include_no_ext: bool = False) -> str:
 
 
 def is_python_source(filename: str | None) -> bool:
-    """
-    return: True if the filename is a python source file
-    """
+    """Return: True if the filename is a python source file."""
     if not filename:
         return False
     return os.path.splitext(filename)[1][1:] in PY_SOURCE_EXTS
 
 
+def is_stdlib_module(modname: str) -> bool:
+    """Return: True if the modname is in the standard library"""
+    return modname.split(".")[0] in stdlib_module_names
+
+
+def module_in_path(modname: str, path: str | Iterable[str]) -> bool:
+    """Try to determine if a module is imported from one of the specified paths
+
+    :param modname: name of the module
+
+    :param path: paths to consider
+
+    :return:
+      true if the module:
+      - is located on the path listed in one of the directory in `paths`
+    """
+
+    modname = modname.split(".")[0]
+    try:
+        filename = file_from_modpath([modname])
+    except ImportError:
+        # Import failed, we can't check path if we don't know it
+        return False
+
+    if filename is None:
+        # No filename likely means it's compiled in, or potentially a namespace
+        return False
+    filename = _normalize_path(filename)
+
+    if isinstance(path, str):
+        return filename.startswith(_cache_normalize_path(path))
+
+    return any(filename.startswith(_cache_normalize_path(entry)) for entry in path)
+
+
 def is_standard_module(modname: str, std_path: Iterable[str] | None = None) -> bool:
-    """try to guess if a module is a standard python module (by default,
-    see `std_path` parameter's description)
+    """Try to guess if a module is a standard python module (by default,
+    see `std_path` parameter's description).
 
     :param modname: name of the module we are interested in
 
@@ -524,6 +563,12 @@ def is_standard_module(modname: str, std_path: Iterable[str] | None = None) -> b
       - is located on the path listed in one of the directory in `std_path`
       - is a built-in module
     """
+    warnings.warn(
+        "is_standard_module() is deprecated. Use, is_stdlib_module() or module_in_path() instead",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+
     modname = modname.split(".")[0]
     try:
         filename = file_from_modpath([modname])
@@ -547,8 +592,8 @@ def is_standard_module(modname: str, std_path: Iterable[str] | None = None) -> b
 
 
 def is_relative(modname: str, from_file: str) -> bool:
-    """return true if the given module name is relative to the given
-    file name
+    """Return true if the given module name is relative to the given
+    file name.
 
     :param modname: name of the module we are interested in
 
@@ -577,8 +622,8 @@ def _spec_from_modpath(
     path: Sequence[str] | None = None,
     context: str | None = None,
 ) -> spec.ModuleSpec:
-    """given a mod path (i.e. split module / package name), return the
-    corresponding spec
+    """Given a mod path (i.e. split module / package name), return the
+    corresponding spec.
 
     this function is used internally, see `file_from_modpath`'s
     documentation for more information
@@ -614,19 +659,19 @@ def _spec_from_modpath(
 
 
 def _is_python_file(filename: str) -> bool:
-    """return true if the given filename should be considered as a python file
+    """Return true if the given filename should be considered as a python file.
 
     .pyc and .pyo are ignored
     """
-    return filename.endswith((".py", ".so", ".pyd", ".pyw"))
+    return filename.endswith((".py", ".pyi", ".so", ".pyd", ".pyw"))
 
 
 def _has_init(directory: str) -> str | None:
-    """if the given directory has a valid __init__ file, return its path,
-    else return None
+    """If the given directory has a valid __init__ file, return its path,
+    else return None.
     """
     mod_or_pack = os.path.join(directory, "__init__")
-    for ext in PY_SOURCE_EXTS + ("pyc", "pyo"):
+    for ext in (*PY_SOURCE_EXTS, "pyc", "pyo"):
         if os.path.exists(mod_or_pack + "." + ext):
             return mod_or_pack + "." + ext
     return None
@@ -644,7 +689,7 @@ def is_module_name_part_of_extension_package_whitelist(
     module_name: str, package_whitelist: set[str]
 ) -> bool:
     """
-    Returns True if one part of the module name is in the package whitelist
+    Returns True if one part of the module name is in the package whitelist.
 
     >>> is_module_name_part_of_extension_package_whitelist('numpy.core.umath', {'numpy'})
     True
