@@ -1,30 +1,29 @@
-# Copyright (c) 2015-2016, 2018, 2020 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2016 Ceridwen <ceridwenv@gmail.com>
-# Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
-# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/COPYING.LESSER
-
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 """Hooks for nose library."""
 
 import re
 import textwrap
 
-import astroid
-import astroid.builder
+from astroid.bases import BoundMethod
+from astroid.brain.helpers import register_module_extender
+from astroid.builder import AstroidBuilder
+from astroid.exceptions import InferenceError
+from astroid.manager import AstroidManager
+from astroid.nodes import List, Module
 
-_BUILDER = astroid.builder.AstroidBuilder(astroid.MANAGER)
+CAPITALS = re.compile("([A-Z])")
 
 
-def _pep8(name, caps=re.compile("([A-Z])")):
+def _pep8(name, caps=CAPITALS):
     return caps.sub(lambda m: "_" + m.groups()[0].lower(), name)
 
 
 def _nose_tools_functions():
     """Get an iterator of names and bound methods."""
-    module = _BUILDER.string_build(
+    module = AstroidBuilder().string_build(
         textwrap.dedent(
             """
     import unittest
@@ -37,15 +36,15 @@ def _nose_tools_functions():
     )
     try:
         case = next(module["a"].infer())
-    except astroid.InferenceError:
+    except (InferenceError, StopIteration):
         return
     for method in case.methods():
         if method.name.startswith("assert") and "_" not in method.name:
             pep8_name = _pep8(method.name)
-            yield pep8_name, astroid.BoundMethod(method, case)
+            yield pep8_name, BoundMethod(method, case)
         if method.name == "assertEqual":
             # nose also exports assert_equals.
-            yield "assert_equals", astroid.BoundMethod(method, case)
+            yield "assert_equals", BoundMethod(method, case)
 
 
 def _nose_tools_transform(node):
@@ -55,7 +54,7 @@ def _nose_tools_transform(node):
 
 def _nose_tools_trivial_transform():
     """Custom transform for the nose.tools module."""
-    stub = _BUILDER.string_build("""__all__ = []""")
+    stub = AstroidBuilder().string_build("""__all__ = []""")
     all_entries = ["ok_", "eq_"]
 
     for pep8_name, method in _nose_tools_functions():
@@ -65,15 +64,16 @@ def _nose_tools_trivial_transform():
     # Update the __all__ variable, since nose.tools
     # does this manually with .append.
     all_assign = stub["__all__"].parent
-    all_object = astroid.List(all_entries)
+    all_object = List(all_entries)
     all_object.parent = all_assign
     all_assign.value = all_object
     return stub
 
 
-astroid.register_module_extender(
-    astroid.MANAGER, "nose.tools.trivial", _nose_tools_trivial_transform
-)
-astroid.MANAGER.register_transform(
-    astroid.Module, _nose_tools_transform, lambda n: n.name == "nose.tools"
-)
+def register(manager: AstroidManager) -> None:
+    register_module_extender(
+        manager, "nose.tools.trivial", _nose_tools_trivial_transform
+    )
+    manager.register_transform(
+        Module, _nose_tools_transform, lambda n: n.name == "nose.tools"
+    )
