@@ -1,6 +1,6 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 """Astroid hooks for scipy.signal module."""
 from astroid.brain.helpers import register_module_extender
@@ -85,4 +85,5 @@ def scipy_signal():
     )
 
 
-register_module_extender(AstroidManager(), "scipy.signal", scipy_signal)
+def register(manager: AstroidManager) -> None:
+    register_module_extender(manager, "scipy.signal", scipy_signal)
